.. pysiriproxy documentation master file, created by
   sphinx-quickstart on Tue Apr 10 17:30:28 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pysiriproxy
==============================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   installation
   configuration
   running
   writing_plugins
   _generated/mod_pysiriproxy
   changelog

.. toctree::
   :hidden:

   writing_objectFilters
   writing_speechRules

Indices and tables
=====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

